@@ -1346,7 +1346,7 @@ def install_python(home_dir, lib_dir, inc_dir, bin_dir, site_packages, clear, sy
                 raise
 
         # Resign the executable, since install_name_tool invalidates the signature
-        call_subprocess(["codesign", "-s", "-", py_executable])
+        call_subprocess(["codesign", "-fs", "-", py_executable])
 
     if not is_win:
         # Ensure that 'python', 'pythonX' and 'pythonX.Y' all exist
