@@ -21,8 +21,8 @@
  * SOFTWARE.
  */
 
-#ifndef __Hacl_Chacha20Poly1305_32_H
-#define __Hacl_Chacha20Poly1305_32_H
+#ifndef __Hacl_Chacha20Poly1305_256_H
+#define __Hacl_Chacha20Poly1305_256_H
 
 #if defined(__cplusplus)
 extern "C" {
@@ -33,12 +33,12 @@ extern "C" {
 #include "krml/lowstar_endianness.h"
 #include "krml/internal/target.h"
 
-#include "Hacl_Poly1305_32.h"
+#include "Hacl_Poly1305_256.h"
 #include "Hacl_Krmllib.h"
-#include "Hacl_Chacha20.h"
+#include "Hacl_Chacha20_Vec256.h"
 
 void
-Hacl_Chacha20Poly1305_32_aead_encrypt(
+Hacl_Chacha20Poly1305_256_aead_encrypt(
     uint8_t *k,
     uint8_t *n,
     uint32_t aadlen,
@@ -49,7 +49,7 @@ Hacl_Chacha20Poly1305_32_aead_encrypt(
     uint8_t *mac);
 
 uint32_t
-Hacl_Chacha20Poly1305_32_aead_decrypt(
+Hacl_Chacha20Poly1305_256_aead_decrypt(
     uint8_t *k,
     uint8_t *n,
     uint32_t aadlen,
@@ -63,5 +63,5 @@ Hacl_Chacha20Poly1305_32_aead_decrypt(
 }
 #endif
 
-#define __Hacl_Chacha20Poly1305_32_H_DEFINED
+#define __Hacl_Chacha20Poly1305_256_H_DEFINED
 #endif
